==> prostore-apollo-react-0.0.16.tgz: package/src/useGraphqlWatchQuery.ts <==
import { DependencyList, useMemo } from 'react';
import {
  GraphqlWatchQueryStore,
  IGraphqlWatchQueryStoreParams
} from '@proscom/prostore-apollo';
import { useRequestStore } from '@proscom/prostore-react';
import { useContextApolloClient } from './ApolloClientsContext';
import { ApolloClient } from 'apollo-client';

export interface IUseGraphqlWatchQueryParams<Vars, Data> {
  client?: string | ApolloClient<any>;
  queryOptions?: IGraphqlWatchQueryStoreParams<Vars, Data>;
  variables?: Vars;
}

/**
 * Создает graphql watchQuery и подписывается на него
 * @param client - Apollo Client instance
 * @param queryOptions - Параметры запроса
 * @param variables - Переменные запроса
 * @returns {{load, check, state}} - Состояние запроса
 */
export function useGraphqlWatchQuery<Vars, Data>({
  client,
  queryOptions,
  variables
}: IUseGraphqlWatchQueryParams<Vars, Data>) {
  const actualClient = useContextApolloClient(client);

  const store = useMemo(
    () =>
      new GraphqlWatchQueryStore({
        client: actualClient,
        ...queryOptions
      }),
    [actualClient, queryOptions]
  );

  return useRequestStore(store, variables);
}

export interface IUseGraphWatchQueryVarsParams<Vars, Data>
  extends IUseGraphqlWatchQueryParams<Vars, Data> {
  variableCreator: [() => Vars, DependencyList];
}

export function useGraphqlWatchQueryVars<Vars, Data>({
  variableCreator,
  ...queryProps
}: IUseGraphWatchQueryVarsParams<Vars, Data>) {
  const variables = useMemo(...variableCreator);
  return useGraphqlWatchQuery({ ...queryProps, variables });
}

==> prostore-apollo-react-0.0.19.tgz: package/src/useGraphqlWatchQuery.ts <==
import { DependencyList, useMemo } from 'react';
import {
  GraphqlWatchQueryStore, IGraphqlWatchQueryOptions,
  IGraphqlWatchQueryStoreParams,
} from '@proscom/prostore-apollo';
import { useRequestStore } from '@proscom/prostore-react';
import { useContextApolloClient } from './ApolloClientsContext';
import { ApolloClient } from 'apollo-client';

export interface IUseGraphqlWatchQueryParams<Vars, Data> {
  client?: string | ApolloClient<any>;
  queryOptions?: IGraphqlWatchQueryStoreParams<Vars, Data>;
  variables?: Vars;
  options?: IGraphqlWatchQueryOptions<Vars>
}

/**
 * Создает graphql watchQuery и подписывается на него
 * @param client - Apollo Client instance
 * @param queryOptions - Параметры запроса
 * @param variables - Переменные запроса
 * @returns {{load, check, state}} - Состояние запроса
 */
export function useGraphqlWatchQuery<Vars, Data>({
  client,
  queryOptions,
  variables,
  options
}: IUseGraphqlWatchQueryParams<Vars, Data>) {
  const actualClient = useContextApolloClient(client);

  const store = useMemo(
    () =>
      new GraphqlWatchQueryStore({
        client: actualClient,
        ...queryOptions
      }),
    [actualClient, queryOptions]
  );

  return useRequestStore(store, variables, options);
}

export interface IUseGraphWatchQueryVarsParams<Vars, Data>
  extends IUseGraphqlWatchQueryParams<Vars, Data> {
  variableCreator: [() => Vars, DependencyList];
}

export function useGraphqlWatchQueryVars<Vars, Data>({
  variableCreator,
  ...queryProps
}: IUseGraphWatchQueryVarsParams<Vars, Data>) {
  const variables = useMemo(...variableCreator);
  return useGraphqlWatchQuery({ ...queryProps, variables });
}
